<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="zh_CN" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../ReText/config.py" line="91"/>
        <source>Using configuration file at:</source>
        <translation>使用配置文件：</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Behavior</source>
        <translation>行为</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Automatically save documents</source>
        <translation>自动保存文件</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Automatically open last documents on startup</source>
        <translation>启动时自动打开上一个文档</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Number of recent documents</source>
        <translation>最近文件数</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Restore window geometry</source>
        <translation>恢复窗口位置大小</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Default preview state</source>
        <translation>默认上次状态</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Open external links in ReText window</source>
        <translation>在 ReText 窗口中打开外部链接</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>Markdown 语法扩展 (逗号分隔)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation>对Markdown开启编辑与预览的同步滚动</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="184"/>
        <source>Editor</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Highlight current line</source>
        <translation>高亮显示当前行</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Show line numbers</source>
        <translation>显示行号</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Line numbers are relative to current line</source>
        <translation>行号与当前行相关</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Tab key inserts spaces</source>
        <translation>使用 空格 替换 Tab</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Tabulation width</source>
        <translation>Tab 键宽度</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Draw vertical line at column</source>
        <translation>画出垂直边界线</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Enable soft wrap</source>
        <translation>启用软包装</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Show document stats</source>
        <translation>显示文档统计信息</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Ordered list mode</source>
        <translation>有序列表模式</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Interface</source>
        <translation>交互界面</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Hide toolbar</source>
        <translation>隐藏标题栏</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Icon theme name</source>
        <translation>图标主题名称</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Stylesheet file</source>
        <translation>样式表文件</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Hide tabs bar when there is only one tab</source>
        <translation>只有一个选项卡时隐藏选项卡栏</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Show full path in window title</source>
        <translation>窗口标题显示全部路径</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Show directory tree</source>
        <translation>显示文件夹结构</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Working directory</source>
        <translation>工作目录</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="166"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="185"/>
        <source>Live preview</source>
        <translation>实时预览</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="186"/>
        <source>Normal preview</source>
        <translation>正常预览</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="191"/>
        <source>Disabled</source>
        <translation>禁止</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="192"/>
        <source>Cursor Line</source>
        <translation>光标线</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="193"/>
        <source>Wrapped Line</source>
        <translation>包装线</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="198"/>
        <source>Increment</source>
        <translation>增量</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="199"/>
        <source>Repeat</source>
        <translation>重复</translation>
    </message>
</context>
<context>
    <name>DirectorySelectButton</name>
    <message>
        <location filename="../ReText/config.py" line="60"/>
        <source>Select directory to open</source>
        <translation>选择要打开的目录</translation>
    </message>
</context>
<context>
    <name>FileDialogButton</name>
    <message>
        <location filename="../ReText/config.py" line="35"/>
        <source>(none)</source>
        <translation>（无）</translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="../ReText/config.py" line="52"/>
        <source>Select file to open</source>
        <translation>打开文件</translation>
    </message>
</context>
<context>
    <name>InsertTableDialog</name>
    <message>
        <location filename="../ReText/tabledialog.py" line="27"/>
        <source>Insert table</source>
        <translation>插入表格</translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="36"/>
        <source>Number of rows</source>
        <translation>行数</translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="37"/>
        <source>Number of columns</source>
        <translation>列数</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../ReText/dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>输入语言名称 (例如: zh_CN)</translation>
    </message>
    <message>
        <location filename="../ReText/dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>设为默认</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="61"/>
        <source>No write since last change (add ! to override)</source>
        <translation>已修改但尚未保存（可用 ! 强制执行）</translation>
    </message>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="118"/>
        <source>Information</source>
        <translation>信息</translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="../ReText/editor.py" line="248"/>
        <source>Add to dictionary</source>
        <translation>添加到词典</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="460"/>
        <source>Save image</source>
        <translation>保存图片</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="460"/>
        <source>Images (*.png *.jpg)</source>
        <translation>图片 (*.png *.jpg)</translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="../ReText/tab.py" line="185"/>
        <source>New document</source>
        <translation>新建文档</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="190"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>不能粘贴文件内容，检查下是否安装了 &lt;a href=&quot;%s&quot;&gt;必要模块&lt;/a&gt; ！</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="497"/>
        <source>Create missing file?</source>
        <translation>创建丢失文件？</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="497"/>
        <source>The file &apos;%s&apos; does not exist.

Do you want to create it?</source>
        <translation>&apos;%s&apos; 不存在。
是否创建？</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="530"/>
        <source>File could not be created</source>
        <translation>无法创建文件</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="530"/>
        <source>Could not create file &apos;%s&apos;: %s</source>
        <translation>无法创建文件 &apos;%s&apos;: %s</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="../ReText/window.py" line="94"/>
        <source>File toolbar</source>
        <translation>文件工具栏</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="96"/>
        <source>Edit toolbar</source>
        <translation>编辑工具栏</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="98"/>
        <source>Search toolbar</source>
        <translation>搜索工具栏</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="102"/>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="104"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="106"/>
        <source>Set encoding</source>
        <translation>设置文本编码格式</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1231"/>
        <source>Reload</source>
        <translation>重新加载</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="112"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="115"/>
        <source>Save as</source>
        <translation>另存为</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="117"/>
        <source>Next tab</source>
        <translation>下一个标签</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="119"/>
        <source>Previous tab</source>
        <translation>上一个标签</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="121"/>
        <source>Close tab</source>
        <translation>关闭标签</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="123"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="125"/>
        <source>Print preview</source>
        <translation>打印预览</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="127"/>
        <source>View HTML code</source>
        <translation>查看 HTML 代码</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="128"/>
        <source>Change editor font</source>
        <translation>修改编辑器字体</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="130"/>
        <source>Change preview font</source>
        <translation>修改预览字体</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="132"/>
        <source>Find text</source>
        <translation>查找文本</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="719"/>
        <source>Go to line</source>
        <translation>到行处</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="137"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="147"/>
        <source>Live preview</source>
        <translation>实时预览</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="151"/>
        <source>Insert table</source>
        <translation>插入表格</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="153"/>
        <source>Table editing mode</source>
        <translation>表格编辑模式</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="156"/>
        <source>Insert images by file path</source>
        <translation>通过文件路径插入图片</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="159"/>
        <source>FakeVim mode</source>
        <translation>FakeVim 模式</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="164"/>
        <source>Fullscreen mode</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="671"/>
        <source>Preferences</source>
        <translation>个人偏好设定</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="174"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="177"/>
        <source>Undo</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="179"/>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="181"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="183"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="185"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="187"/>
        <source>Paste image</source>
        <translation>粘贴图片</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="189"/>
        <source>Move line up</source>
        <translation>上移</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="191"/>
        <source>Move line down</source>
        <translation>下移</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="200"/>
        <source>Enable</source>
        <translation>激活</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="201"/>
        <source>Set locale</source>
        <translation>选择界面语言</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="202"/>
        <source>Use WebKit renderer</source>
        <translation>使用 WebKit 渲染</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="207"/>
        <source>Use WebEngine (Chromium) renderer</source>
        <translation>使用 WebEngine (Chromium)  渲染器</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="212"/>
        <source>Show directory</source>
        <translation>显示文件夹</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="213"/>
        <source>Next</source>
        <translation>下一项</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="215"/>
        <source>Previous</source>
        <translation>上一项</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="217"/>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="219"/>
        <source>Replace all</source>
        <translation>替换所有</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="222"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="226"/>
        <source>Get help online</source>
        <translation>在线获取帮助（英文）</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="227"/>
        <source>About ReText</source>
        <translation>关于 ReText</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="230"/>
        <source>About Qt</source>
        <translation>关于 Qt</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="245"/>
        <source>Bold</source>
        <translation>粗体</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="247"/>
        <source>Italic</source>
        <translation>斜体</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="249"/>
        <source>Underline</source>
        <translation>下划线</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="325"/>
        <source>Formatting</source>
        <translation>字符样式</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="265"/>
        <source>Symbols</source>
        <translation>符号</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="270"/>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="271"/>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="272"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="275"/>
        <source>Open recent</source>
        <translation>打开最近使用</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="288"/>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="313"/>
        <source>Spell check</source>
        <translation>拼写检查</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="322"/>
        <source>Default markup</source>
        <translation>默认编辑模式</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="372"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="375"/>
        <source>Replace with</source>
        <translation>替换为</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="377"/>
        <source>Case sensitively</source>
        <translation>对大小写敏感</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="567"/>
        <source>New document</source>
        <translation>新文件</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="719"/>
        <source>Type the line number</source>
        <translation>输入数字</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="755"/>
        <source>Please, save the file somewhere.</source>
        <translation>请保存到别处！</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="871"/>
        <source>Select one or several files to open</source>
        <translation>选择一个或多个文件打开</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1289"/>
        <source>Supported files</source>
        <translation>支持的文件类型</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1289"/>
        <source>All files (*)</source>
        <translation>全部文件 (*)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="910"/>
        <source>Select file encoding from the list:</source>
        <translation>从列表中选择文件编码方式</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="933"/>
        <source>Plain text (*.txt)</source>
        <translation>普通文本文档 (*.txt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="936"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s 文件</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1011"/>
        <source>Save file</source>
        <translation>保存文件</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="956"/>
        <source>Cannot save to file which is open in another tab!</source>
        <translation>已在其它标签处打开，当前无法保存。</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="979"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>不能保存文件因为当前文件或文件夹只读！</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1001"/>
        <source>Export document to ODT</source>
        <translation>导出为 ODT 文档</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1001"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument 文本文件 (*.odt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1011"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML 文件 (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1034"/>
        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
        <translation>无法识别的纸张大小设置 &quot;%s&quot;</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1060"/>
        <source>Export document to PDF</source>
        <translation>导出格式为 PDF</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1060"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF 文件 (*.pdf)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1087"/>
        <source>Print document</source>
        <translation>打印文件</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1110"/>
        <source>Export document</source>
        <translation>导出文件</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1131"/>
        <source>Failed to execute the command:</source>
        <translation>不能执行命令:</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1172"/>
        <source>Alt text</source>
        <translation>替换文本</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1173"/>
        <source>URL</source>
        <translation>链接</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1173"/>
        <source>Link text</source>
        <translation>链接文本</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1214"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>该文件已被其它程序删除。
请确认在退出前保存。</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1222"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>文件已被其它程序修改。
要重新载入文件（放弃当前所有修改）吗？
</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1227"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>如果不重新载入文件，为防止数据丢失，将禁用该会话的自动保存模式。</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1251"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>文件已更改，确认保存吗？</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1279"/>
        <source>HTML code</source>
        <translation>HTML 代码</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1289"/>
        <source>Select one or several images to open</source>
        <translation>选择要打开的图片</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation>ReText %s（使用 PyMarkups %s）</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>简单高效的 Markdown 与 ReStructuredText 编辑器</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>作者: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>Markdown syntax</source>
        <translation>Markdown 语法</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>reStructuredText syntax</source>
        <translation>reStructuredText 语法</translation>
    </message>
</context>
<context>
    <name>TextInfoArea</name>
    <message>
        <location filename="../ReText/editor.py" line="651"/>
        <source>%d w | %d a | %d c</source>
        <comment>count of words, alphanumeric characters, all characters</comment>
        <translation>%d w | %d a | %d c</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../ReText/__main__.py" line="88"/>
        <source>Open the files in preview mode</source>
        <translation>在预览模式下打开文件</translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="90"/>
        <source>Create a new window even if there is an existing one</source>
        <translation>创建一个新窗口</translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="94"/>
        <source>List of files to open</source>
        <translation>待打开的文件列表</translation>
    </message>
</context>
</TS>
